@@ -402,7 +402,8 @@ def generate_apache_config(options):
                             mount_point=mount_point, directory=directory,
                             filename=filename), file=fp)
 
-        print(APACHE_ALIAS_DOCUMENTATION % options, file=fp)
+        if options['enable_docs']:
+            print(APACHE_ALIAS_DOCUMENTATION % options, file=fp)
 
         if options['error_documents']:
             for status, document in options['error_documents']:
@@ -781,9 +782,15 @@ def generate_control_scripts(options):
     os.chmod(path, 0o755)
 
     path = os.path.join(options['server_root'], 'envvars')
-    with open(path, 'w') as fp:
-        if options['envvars_script']:
-            print(APACHE_ENVVARS_FILE.lstrip() % options, file=fp)
+
+    if options['envvars_script']:
+        with open(path, 'w') as fp:
+            if options['envvars_script']:
+                print(APACHE_ENVVARS_FILE.lstrip() % options, file=fp)
+
+    elif not os.path.isfile(path):
+        with open(path, 'w') as fp:
+            pass
 
 def check_percentage(option, opt_str, value, parser):
     if value is not None and value < 0 or value > 1:
@@ -1055,17 +1062,17 @@ option_list = (
             'be made available at the /__wsgi__/docs sub URL.'),
 )
 
-def cmd_setup_server(params, usage=None):
+def cmd_setup_server(params):
     formatter = optparse.IndentedHelpFormatter()
     formatter.set_long_opt_delimiter(' ')
 
-    usage = usage or '%prog setup-server script [options]'
+    usage = '%prog setup-server script [options]'
     parser = optparse.OptionParser(usage=usage, option_list=option_list,
             formatter=formatter)
 
     (options, args) = parser.parse_args(params)
 
-    return _cmd_setup_server(args, vars(options))
+    _cmd_setup_server('setup-server', args, vars(options))
 
 def _mpm_module_defines(modules_directory):
     result = []
@@ -1076,7 +1083,7 @@ def _mpm_module_defines(modules_directory):
             result.append('-DWSGI_MPM_%s_MODULE' % name.upper())
     return result
 
-def _cmd_setup_server(args, options):
+def _cmd_setup_server(command, args, options):
     options['mod_wsgi_so'] = where()
 
     options['working_directory'] = options['working_directory'] or os.getcwd()
@@ -1326,29 +1333,44 @@ def _cmd_setup_server(args, options):
     generate_apache_config(options)
     generate_control_scripts(options)
 
-    print('Server URL      :', options['url'])
+    print('Server URL        :', options['url'])
 
     if options['server_status']:
-        print('Server Status   :', '%sserver-status' % options['url'])
+        print('Server Status     :', '%sserver-status' % options['url'])
 
-    print('Server Root     :', options['server_root'])
-    print('Server Conf     :', options['httpd_conf'])
+    print('Server Root       :', options['server_root'])
+    print('Server Conf       :', options['httpd_conf'])
 
-    print('Error Log       :', options['error_log'])
+    print('Error Log File    :', options['error_log'])
 
     if options['access_log']:
-        print('Access Log      :', os.path.join(options['log_directory'],
-    'access_log'))
+        print('Access Log File   :', os.path.join(options['log_directory'],
+                'access_log'))
+
+    if options['envvars_script']:
+        print('Environ Variables :', options['envvars_script'])
+
+    if command == 'setup-server':
+        if not options['envvars_script']:
+            print('Environ Variables :', options['server_root'] + '/envvars')
+        print('Control Script    :', options['server_root'] + '/apachectl')
 
     return options
 
 def cmd_start_server(params):
+    formatter = optparse.IndentedHelpFormatter()
+    formatter.set_long_opt_delimiter(' ')
+
     usage = '%prog start-server script [options]'
+    parser = optparse.OptionParser(usage=usage, option_list=option_list,
+            formatter=formatter)
 
-    options = cmd_setup_server(params, usage)
+    (options, args) = parser.parse_args(params)
 
-    executable = os.path.join(options['server_root'], 'apachectl')
-    name = executable.ljust(len(options['process_name']))
+    config = _cmd_setup_server('start-server', args, vars(options))
+
+    executable = os.path.join(config['server_root'], 'apachectl')
+    name = executable.ljust(len(config['process_name']))
     os.execl(executable, name, 'start', '-DNO_DETACH')
 
 def cmd_install_module(params):
